==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTLabeledBlockNode.h <==
// public class soot.dava.internal.AST.ASTLabeledBlockNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 6ef05fd6b8a9db06 soot_dava_internal_AST_ASTLabeledBlockNode
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTLabeledNode

#include "soot/dava/internal/AST/ASTLabeledNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTLabeledBlockNode_H_
#define _JC_soot_dava_internal_AST_ASTLabeledBlockNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$_init$19ea21a534e3d371(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *);
extern jint _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *);
extern void _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods	soot_dava_internal_AST_ASTLabeledBlockNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs {
	struct _jc_object	*body;
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*label;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs {
    _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs	soot_dava_internal_AST_ASTLabeledBlockNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledBlockNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object {
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype _jc_soot_dava_internal_AST_ASTLabeledBlockNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTLabeledBlockNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTLabeledBlockNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTLabeledBlockNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTLabeledBlockNode.h <==
// public class soot.dava.internal.AST.ASTLabeledBlockNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 6ef05fd6b8a9db06 soot_dava_internal_AST_ASTLabeledBlockNode
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTLabeledNode

#include "soot/dava/internal/AST/ASTLabeledNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTLabeledBlockNode_H_
#define _JC_soot_dava_internal_AST_ASTLabeledBlockNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$_init$19ea21a534e3d371(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledBlockNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vmethods	soot_dava_internal_AST_ASTLabeledBlockNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs {
	struct _jc_object	*body;
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*label;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs {
    _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_refs	soot_dava_internal_AST_ASTLabeledBlockNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTLabeledBlockNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledBlockNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTLabeledBlockNode$object {
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTLabeledBlockNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTLabeledBlockNode$vtype _jc_soot_dava_internal_AST_ASTLabeledBlockNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTLabeledBlockNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTLabeledBlockNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTLabeledBlockNode_H_ */
